package common.init;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Set;

import common.block.*;
import common.block.artificial.*;
import common.block.foliage.*;
import common.block.liquid.*;
import common.block.natural.*;
import common.block.tech.*;
import common.block.tile.*;
import common.collect.Lists;
import common.collect.Sets;
import common.util.Util;


public abstract class Blocks {
	public static final BlockDoor acacia_door = get("acacia_door");
	public static final BlockFence acacia_fence = get("acacia_fence");
	public static final BlockFenceGate acacia_fence_gate = get("acacia_fence_gate");
	public static final BlockLeaves acacia_leaves = get("acacia_leaves");
	public static final BlockLog acacia_log = get("acacia_log");
	public static final Block acacia_planks = get("acacia_planks");
	public static final BlockSapling acacia_sapling = get("acacia_sapling");
	public static final BlockSlab acacia_slab = get("acacia_slab");
	public static final BlockStairs acacia_stairs = get("acacia_stairs");
	public static final BlockStaticLiquid acid = get("acid");
	public static final BlockRailPowered activator_rail = get("activator_rail");
	public static final BlockAir air = get("air");
	public static final Block aluminium_block = get("aluminium_block");
	public static final BlockOre aluminium_ore = get("aluminium_ore");
	public static final Block antimony_block = get("antimony_block");
	public static final BlockOre antimony_ore = get("antimony_ore");
	public static final BlockAnvil anvil = get("anvil");
	public static final Block ardite_block = get("ardite_block");
	public static final BlockOre ardite_ore = get("ardite_ore");
	public static final Block arsenic_block = get("arsenic_block");
	public static final BlockOre arsenic_ore = get("arsenic_ore");
	public static final Block ash = get("ash");
	public static final BlockWorkbench assembly_unit = get("assembly_unit");
	public static final BlockBannerStanding banner = get("banner");
	public static final BlockBeacon beacon = get("beacon");
	public static final BlockBedrock bedrock = get("bedrock");
	public static final BlockDoor birch_door = get("birch_door");
	public static final BlockFence birch_fence = get("birch_fence");
	public static final BlockFenceGate birch_fence_gate = get("birch_fence_gate");
	public static final BlockLeaves birch_leaves = get("birch_leaves");
	public static final BlockLog birch_log = get("birch_log");
	public static final Block birch_planks = get("birch_planks");
	public static final BlockSapling birch_sapling = get("birch_sapling");
	public static final BlockSlab birch_slab = get("birch_slab");
	public static final BlockStairs birch_stairs = get("birch_stairs");
	public static final Block bismuth_block = get("bismuth_block");
	public static final BlockOre bismuth_ore = get("bismuth_ore");
	public static final BlockBed black_bed = get("black_bed");
	public static final Block black_brick = get("black_brick");
	public static final BlockFence black_brick_fence = get("black_brick_fence");
	public static final BlockSlab black_brick_slab = get("black_brick_slab");
	public static final BlockStairs black_brick_stairs = get("black_brick_stairs");
	public static final BlockTintedFire black_fire = get("black_fire");
	public static final Block black_metal_block = get("black_metal_block");
	public static final BlockOre black_metal_ore = get("black_metal_ore");
	public static final BlockQuartz black_quartz_block = get("black_quartz_block");
	public static final BlockOre black_quartz_ore = get("black_quartz_ore");
	public static final BlockSlab black_quartz_slab = get("black_quartz_slab");
	public static final BlockStairs black_quartz_stairs = get("black_quartz_stairs");
	public static final Block blackened_cobble = get("blackened_cobble");
	public static final BlockBlackenedDirt blackened_dirt = get("blackened_dirt");
	public static final BlockBlackenedSoil blackened_soil = get("blackened_soil");
	public static final BlockBlackenedStone blackened_stone = get("blackened_stone");
	public static final BlockDoor blackwood_door = get("blackwood_door");
	public static final BlockFence blackwood_fence = get("blackwood_fence");
	public static final BlockFenceGate blackwood_fence_gate = get("blackwood_fence_gate");
	public static final BlockLeaves blackwood_leaves = get("blackwood_leaves");
	public static final BlockLog blackwood_log = get("blackwood_log");
	public static final Block blackwood_planks = get("blackwood_planks");
	public static final BlockSapling blackwood_sapling = get("blackwood_sapling");
	public static final BlockSlab blackwood_slab = get("blackwood_slab");
	public static final BlockStairs blackwood_stairs = get("blackwood_stairs");
	public static final BlockStaticLiquid blood = get("blood");
	public static final Block blood_brick = get("blood_brick");
	public static final BlockFence blood_brick_fence = get("blood_brick_fence");
	public static final BlockSlab blood_brick_slab = get("blood_brick_slab");
	public static final BlockStairs blood_brick_stairs = get("blood_brick_stairs");
	public static final BlockBlueShroom blue_mushroom = get("blue_mushroom");
	public static final BlockBookshelf bookshelf = get("bookshelf");
	public static final BlockBrewingStand brewing_stand = get("brewing_stand");
	public static final Block brick_block = get("brick_block");
	public static final BlockSlab brick_slab = get("brick_slab");
	public static final BlockStairs brick_stairs = get("brick_stairs");
	public static final BlockMushroom brown_mushroom = get("brown_mushroom");
	public static final BlockHugeMushroom brown_mushroom_block = get("brown_mushroom_block");
	public static final BlockCactus cactus = get("cactus");
	public static final BlockCake cake = get("cake");
	public static final Block calcium_block = get("calcium_block");
	public static final BlockOre calcium_ore = get("calcium_ore");
	public static final BlockCarpet carpet = get("carpet");
	public static final BlockCarrot carrot = get("carrot");
	public static final BlockCauldron cauldron = get("cauldron");
	public static final Block cell_rock = get("cell_rock");
	public static final BlockDoor cherry_door = get("cherry_door");
	public static final BlockFence cherry_fence = get("cherry_fence");
	public static final BlockFenceGate cherry_fence_gate = get("cherry_fence_gate");
	public static final BlockLeaves cherry_leaves = get("cherry_leaves");
	public static final BlockLog cherry_log = get("cherry_log");
	public static final Block cherry_planks = get("cherry_planks");
	public static final BlockSapling cherry_sapling = get("cherry_sapling");
	public static final BlockSlab cherry_slab = get("cherry_slab");
	public static final BlockStairs cherry_stairs = get("cherry_stairs");
	public static final BlockChest chest = get("chest");
	public static final Block chrome_block = get("chrome_block");
	public static final BlockOre chrome_ore = get("chrome_ore");
	public static final Block cinnabar_block = get("cinnabar_block");
	public static final BlockOre cinnabar_ore = get("cinnabar_ore");
	public static final BlockClay clay = get("clay");
	public static final Block coal_block = get("coal_block");
	public static final BlockOre coal_ore = get("coal_ore");
	public static final Block cobalt_block = get("cobalt_block");
	public static final BlockOre cobalt_ore = get("cobalt_ore");
	public static final Block cobblestone = get("cobblestone");
	public static final BlockSlab cobblestone_slab = get("cobblestone_slab");
	public static final BlockStairs cobblestone_stairs = get("cobblestone_stairs");
	public static final BlockWall cobblestone_wall = get("cobblestone_wall");
	public static final BlockCocoa cocoa = get("cocoa");
	public static final BlockRedstoneComparator comparator = get("comparator");
	public static final BlockWorkbench construction_table = get("construction_table");
	public static final Block copper_block = get("copper_block");
	public static final BlockOre copper_ore = get("copper_ore");
	public static final BlockCore core = get("core");
	public static final BlockDoor dark_oak_door = get("dark_oak_door");
	public static final BlockFence dark_oak_fence = get("dark_oak_fence");
	public static final BlockFenceGate dark_oak_fence_gate = get("dark_oak_fence_gate");
	public static final BlockLeaves dark_oak_leaves = get("dark_oak_leaves");
	public static final BlockLog dark_oak_log = get("dark_oak_log");
	public static final Block dark_oak_planks = get("dark_oak_planks");
	public static final BlockSapling dark_oak_sapling = get("dark_oak_sapling");
	public static final BlockSlab dark_oak_slab = get("dark_oak_slab");
	public static final BlockStairs dark_oak_stairs = get("dark_oak_stairs");
	public static final BlockDaylightDetector daylight_detector = get("daylight_detector");
	public static final BlockDaylightDetector daylight_detector_inverted = get("daylight_detector_inverted");
	public static final BlockDeadBush deadbush = get("deadbush");
	public static final BlockRailDetector detector_rail = get("detector_rail");
	public static final Block diamond_block = get("diamond_block");
	public static final BlockOre diamond_ore = get("diamond_ore");
	public static final BlockDirt dirt = get("dirt");
	public static final BlockDispenser dispenser = get("dispenser");
	public static final BlockDoublePlant double_plant = get("double_plant");
	public static final BlockDragonEgg dragon_egg = get("dragon_egg");
	public static final BlockDropper dropper = get("dropper");
	public static final BlockDryLeaves dry_leaves = get("dry_leaves");
	public static final Block emerald_block = get("emerald_block");
	public static final BlockOre emerald_ore = get("emerald_ore");
	public static final BlockEnchantmentTable enchanting_table = get("enchanting_table");
	public static final BlockFarmland farmland = get("farmland");
	public static final BlockFire fire = get("fire");
	public static final BlockFloorPortal floor_portal = get("floor_portal");
	public static final Block floor_tiles = get("floor_tiles");
	public static final Block floor_tiles_black = get("floor_tiles_black");
	public static final Block floor_tiles_red = get("floor_tiles_red");
	public static final Block floor_tiles_white = get("floor_tiles_white");
	public static final BlockBaseFlower flower = get("flower");
	public static final BlockFlowerPot flower_pot = get("flower_pot");
	public static final BlockDynamicLiquid flowing_acid = get("flowing_acid");
	public static final BlockDynamicLiquid flowing_blood = get("flowing_blood");
	public static final BlockDynamicLiquid flowing_goo = get("flowing_goo");
	public static final BlockDynamicLiquid flowing_hydrogen = get("flowing_hydrogen");
	public static final BlockDynamicLiquid flowing_lava = get("flowing_lava");
	public static final BlockDynamicLiquid flowing_magma = get("flowing_magma");
	public static final BlockDynamicLiquid flowing_mercury = get("flowing_mercury");
	public static final BlockDynamicLiquid flowing_nukage = get("flowing_nukage");
	public static final BlockDynamicLiquid flowing_slime = get("flowing_slime");
	public static final BlockDynamicLiquid flowing_water = get("flowing_water");
	public static final BlockFurnace furnace = get("furnace");
	public static final BlockGlass glass = get("glass");
	public static final BlockPane glass_pane = get("glass_pane");
	public static final BlockGlowstone glowstone = get("glowstone");
	public static final Block gold_block = get("gold_block");
	public static final BlockOre gold_ore = get("gold_ore");
	public static final BlockRailPowered golden_rail = get("golden_rail");
	public static final BlockStaticLiquid goo = get("goo");
	public static final BlockGrass grass = get("grass");
	public static final BlockGravel gravel = get("gravel");
	public static final Block gyriyn_block = get("gyriyn_block");
	public static final BlockOre gyriyn_ore = get("gyriyn_ore");
	public static final BlockHardenedClay hardened_clay = get("hardened_clay");
	public static final BlockHay hay_block = get("hay_block");
	public static final BlockPressurePlateWeighted heavy_weighted_pressure_plate = get("heavy_weighted_pressure_plate");
	public static final BlockHellRock hellrock = get("hellrock");
	public static final BlockHopper hopper = get("hopper");
	public static final BlockStaticLiquid hydrogen = get("hydrogen");
	public static final BlockIce ice = get("ice");
	public static final Block iodine_block = get("iodine_block");
	public static final BlockOre iodine_ore = get("iodine_ore");
	public static final BlockPane iron_bars = get("iron_bars");
	public static final Block iron_block = get("iron_block");
	public static final BlockDoor iron_door = get("iron_door");
	public static final BlockOre iron_ore = get("iron_ore");
	public static final BlockTrapDoor iron_trapdoor = get("iron_trapdoor");
	public static final BlockJukebox jukebox = get("jukebox");
	public static final BlockDoor jungle_door = get("jungle_door");
	public static final BlockFence jungle_fence = get("jungle_fence");
	public static final BlockFenceGate jungle_fence_gate = get("jungle_fence_gate");
	public static final BlockLeaves jungle_leaves = get("jungle_leaves");
	public static final BlockLog jungle_log = get("jungle_log");
	public static final Block jungle_planks = get("jungle_planks");
	public static final BlockSapling jungle_sapling = get("jungle_sapling");
	public static final BlockSlab jungle_slab = get("jungle_slab");
	public static final BlockStairs jungle_stairs = get("jungle_stairs");
	public static final BlockLadder ladder = get("ladder");
	public static final Block lamp = get("lamp");
	public static final Block lapis_block = get("lapis_block");
	public static final BlockOre lapis_ore = get("lapis_ore");
	public static final BlockStaticLiquid lava = get("lava");
	public static final Block lead_block = get("lead_block");
	public static final BlockOre lead_ore = get("lead_ore");
	public static final BlockLever lever = get("lever");
	public static final BlockPressurePlateWeighted light_weighted_pressure_plate = get("light_weighted_pressure_plate");
	public static final BlockFurnace lit_furnace = get("lit_furnace");
	public static final BlockPumpkin lit_pumpkin = get("lit_pumpkin");
	public static final BlockRedstoneLight lit_redstone_lamp = get("lit_redstone_lamp");
	public static final BlockRedstoneOre lit_redstone_ore = get("lit_redstone_ore");
	public static final Block lithium_block = get("lithium_block");
	public static final BlockOre lithium_ore = get("lithium_ore");
	public static final BlockStaticLiquid magma = get("magma");
	public static final Block magnesium_block = get("magnesium_block");
	public static final BlockOre magnesium_ore = get("magnesium_ore");
	public static final Block manganese_block = get("manganese_block");
	public static final BlockOre manganese_ore = get("manganese_ore");
	public static final BlockDoor maple_door = get("maple_door");
	public static final BlockFence maple_fence = get("maple_fence");
	public static final BlockFenceGate maple_fence_gate = get("maple_fence_gate");
	public static final BlockLeaves maple_leaves = get("maple_leaves");
	public static final BlockLog maple_log = get("maple_log");
	public static final Block maple_planks = get("maple_planks");
	public static final BlockSapling maple_sapling = get("maple_sapling");
	public static final BlockSlab maple_slab = get("maple_slab");
	public static final BlockStairs maple_stairs = get("maple_stairs");
	public static final BlockMelon melon_block = get("melon_block");
	public static final BlockStem melon_stem = get("melon_stem");
	public static final BlockStaticLiquid mercury = get("mercury");
	public static final BlockMobSpawner mob_spawner = get("mob_spawner");
	public static final BlockTreasure moon_cheese = get("moon_cheese");
	public static final Block moon_rock = get("moon_rock");
	public static final Block mossy_cobblestone = get("mossy_cobblestone");
	public static final BlockMycelium mycelium = get("mycelium");
	public static final Block neodymium_block = get("neodymium_block");
	public static final BlockOre neodymium_ore = get("neodymium_ore");
	public static final Block neptunium_block = get("neptunium_block");
	public static final BlockOre neptunium_ore = get("neptunium_ore");
	public static final Block nichun_block = get("nichun_block");
	public static final BlockOre nichun_ore = get("nichun_ore");
	public static final Block nickel_block = get("nickel_block");
	public static final BlockOre nickel_ore = get("nickel_ore");
	public static final BlockNote noteblock = get("noteblock");
	public static final BlockStaticLiquid nukage = get("nukage");
	public static final BlockNuke nuke = get("nuke");
	public static final BlockDoor oak_door = get("oak_door");
	public static final BlockFence oak_fence = get("oak_fence");
	public static final BlockFenceGate oak_fence_gate = get("oak_fence_gate");
	public static final BlockLeaves oak_leaves = get("oak_leaves");
	public static final BlockLog oak_log = get("oak_log");
	public static final Block oak_planks = get("oak_planks");
	public static final BlockSapling oak_sapling = get("oak_sapling");
	public static final BlockSlab oak_slab = get("oak_slab");
	public static final BlockStairs oak_stairs = get("oak_stairs");
	public static final BlockObsidian obsidian = get("obsidian");
	public static final BlockPackedIce packed_ice = get("packed_ice");
	public static final Block palladium_block = get("palladium_block");
	public static final BlockOre palladium_ore = get("palladium_ore");
	public static final Block pentagram = get("pentagram");
	public static final Block phosphor_block = get("phosphor_block");
	public static final BlockOre phosphor_ore = get("phosphor_ore");
	public static final BlockPistonBase piston = get("piston");
	public static final BlockPistonMoving piston_extension = get("piston_extension");
	public static final BlockPistonHead piston_head = get("piston_head");
	public static final Block platinum_block = get("platinum_block");
	public static final BlockOre platinum_ore = get("platinum_ore");
	public static final Block plutonium_block = get("plutonium_block");
	public static final BlockOre plutonium_ore = get("plutonium_ore");
	public static final BlockPortal portal = get("portal");
	public static final BlockPortalFrame portal_frame = get("portal_frame");
	public static final Block potassium_block = get("potassium_block");
	public static final BlockOre potassium_ore = get("potassium_ore");
	public static final BlockPotato potato = get("potato");
	public static final BlockRedstoneComparator powered_comparator = get("powered_comparator");
	public static final BlockRedstoneRepeater powered_repeater = get("powered_repeater");
	public static final Block praseodymium_block = get("praseodymium_block");
	public static final BlockOre praseodymium_ore = get("praseodymium_ore");
	public static final BlockPumpkin pumpkin = get("pumpkin");
	public static final BlockStem pumpkin_stem = get("pumpkin_stem");
	public static final BlockBed purple_bed = get("purple_bed");
	public static final BlockQuartz quartz_block = get("quartz_block");
	public static final BlockOre quartz_ore = get("quartz_ore");
	public static final BlockSlab quartz_slab = get("quartz_slab");
	public static final BlockStairs quartz_stairs = get("quartz_stairs");
	public static final Block radium_block = get("radium_block");
	public static final BlockOre radium_ore = get("radium_ore");
	public static final BlockRail rail = get("rail");
	public static final BlockBed red_bed = get("red_bed");
	public static final BlockButton red_button = get("red_button");
	public static final BlockMushroom red_mushroom = get("red_mushroom");
	public static final BlockHugeMushroom red_mushroom_block = get("red_mushroom_block");
	public static final BlockRedstoneWire redstone = get("redstone");
	public static final BlockCompressedPowered redstone_block = get("redstone_block");
	public static final BlockRedstoneLight redstone_lamp = get("redstone_lamp");
	public static final BlockRedstoneOre redstone_ore = get("redstone_ore");
	public static final BlockRedstoneTorch redstone_torch = get("redstone_torch");
	public static final BlockReed reeds = get("reeds");
	public static final BlockRedstoneRepeater repeater = get("repeater");
	public static final BlockRock rock = get("rock");
	public static final Block ruby_block = get("ruby_block");
	public static final BlockOre ruby_ore = get("ruby_ore");
	public static final BlockSand sand = get("sand");
	public static final BlockSandStone sandstone = get("sandstone");
	public static final BlockSlab sandstone_slab = get("sandstone_slab");
	public static final BlockStairs sandstone_stairs = get("sandstone_stairs");
	public static final Block selenium_block = get("selenium_block");
	public static final BlockOre selenium_ore = get("selenium_ore");
	public static final BlockStandingSign sign = get("sign");
	public static final Block silicon_block = get("silicon_block");
	public static final BlockOre silicon_ore = get("silicon_ore");
	public static final Block silver_block = get("silver_block");
	public static final BlockOre silver_ore = get("silver_ore");
	public static final BlockSkull skull = get("skull");
	public static final BlockStaticLiquid slime = get("slime");
	public static final BlockSlime slime_block = get("slime_block");
	public static final BlockSnowBlock snow = get("snow");
	public static final BlockSnow snow_layer = get("snow_layer");
	public static final Block sodium_block = get("sodium_block");
	public static final BlockOre sodium_ore = get("sodium_ore");
	public static final BlockSoulFire soul_fire = get("soul_fire");
	public static final BlockSoulSand soul_sand = get("soul_sand");
	public static final BlockWart soul_wart = get("soul_wart");
	public static final Block sponge = get("sponge");
	public static final BlockDoor spruce_door = get("spruce_door");
	public static final BlockFence spruce_fence = get("spruce_fence");
	public static final BlockFenceGate spruce_fence_gate = get("spruce_fence_gate");
	public static final BlockLeaves spruce_leaves = get("spruce_leaves");
	public static final BlockLog spruce_log = get("spruce_log");
	public static final Block spruce_planks = get("spruce_planks");
	public static final BlockSapling spruce_sapling = get("spruce_sapling");
	public static final BlockSlab spruce_slab = get("spruce_slab");
	public static final BlockStairs spruce_stairs = get("spruce_stairs");
	public static final BlockStainedGlass stained_glass = get("stained_glass");
	public static final BlockStainedGlassPane stained_glass_pane = get("stained_glass_pane");
	public static final BlockColored stained_hardened_clay = get("stained_hardened_clay");
	public static final BlockPistonBase sticky_piston = get("sticky_piston");
	public static final BlockStone stone = get("stone");
	public static final BlockButton stone_button = get("stone_button");
	public static final BlockPressurePlate stone_pressure_plate = get("stone_pressure_plate");
	public static final BlockSlab stone_slab = get("stone_slab");
	public static final BlockStairs stone_stairs = get("stone_stairs");
	public static final BlockStoneBrick stonebrick = get("stonebrick");
	public static final BlockSlab stonebrick_slab = get("stonebrick_slab");
	public static final BlockStairs stonebrick_stairs = get("stonebrick_stairs");
	public static final BlockTripWire string = get("string");
	public static final Block sulfur_block = get("sulfur_block");
	public static final BlockOre sulfur_ore = get("sulfur_ore");
	public static final BlockTallGrass tallgrass = get("tallgrass");
	public static final Block thetium_block = get("thetium_block");
	public static final BlockOre thetium_ore = get("thetium_ore");
	public static final Block tian = get("tian");
	public static final BlockDoor tian_door = get("tian_door");
	public static final BlockFence tian_fence = get("tian_fence");
	public static final BlockFenceGate tian_fence_gate = get("tian_fence_gate");
	public static final BlockLeaves tian_leaves = get("tian_leaves");
	public static final BlockLog tian_log = get("tian_log");
	public static final Block tian_planks = get("tian_planks");
	public static final BlockTianReactor tian_reactor = get("tian_reactor");
	public static final BlockSapling tian_sapling = get("tian_sapling");
	public static final BlockSlab tian_slab = get("tian_slab");
	public static final BlockTianSoil tian_soil = get("tian_soil");
	public static final BlockStairs tian_stairs = get("tian_stairs");
	public static final Block tin_block = get("tin_block");
	public static final BlockOre tin_ore = get("tin_ore");
	public static final Block titanium_block = get("titanium_block");
	public static final BlockOre titanium_ore = get("titanium_ore");
	public static final BlockTNT tnt = get("tnt");
	public static final BlockTorch torch = get("torch");
	public static final BlockTrapDoor trapdoor = get("trapdoor");
	public static final BlockChest trapped_chest = get("trapped_chest");
	public static final BlockTripWireHook tripwire_hook = get("tripwire_hook");
	public static final Block tungsten_block = get("tungsten_block");
	public static final BlockOre tungsten_ore = get("tungsten_ore");
	public static final BlockRedstoneTorch unlit_redstone_torch = get("unlit_redstone_torch");
	public static final Block uranium_block = get("uranium_block");
	public static final BlockOre uranium_ore = get("uranium_ore");
	public static final Block vanadium_block = get("vanadium_block");
	public static final BlockOre vanadium_ore = get("vanadium_ore");
	public static final BlockVine vine = get("vine");
	public static final BlockBannerHanging wall_banner = get("wall_banner");
	public static final BlockWallSign wall_sign = get("wall_sign");
	public static final BlockWarpChest warp_chest = get("warp_chest");
	public static final BlockStaticLiquid water = get("water");
	public static final BlockLilyPad waterlily = get("waterlily");
	public static final BlockWeb web = get("web");
	public static final BlockCrops wheat = get("wheat");
	public static final BlockBed white_bed = get("white_bed");
	public static final BlockButton wooden_button = get("wooden_button");
	public static final BlockPressurePlate wooden_pressure_plate = get("wooden_pressure_plate");
	public static final BlockColored wool = get("wool");
	public static final BlockWorkbench workbench = get("workbench");
	public static final Block zinc_block = get("zinc_block");
	public static final BlockOre zinc_ore = get("zinc_ore");
	public static final BlockDynamicLiquid flowing_springwater = get("flowing_springwater");
	public static final BlockStaticLiquid springwater = get("springwater");
    
    private static <T extends Block> T get(String id) {
    	if(!BlockRegistry.REGISTRY.containsKey(id))
			throw new RuntimeException("Block " + id + " existiert nicht");
		return (T)BlockRegistry.REGISTRY.getObject(id);
    }
    
    static {
    	if(Util.DEVMODE) {
	    	Set<Block> blocks = Sets.newHashSet(BlockRegistry.REGISTRY);
	    	for(Field field : Blocks.class.getDeclaredFields()) {
	    		if(Modifier.isStatic(field.getModifiers()) && Modifier.isFinal(field.getModifiers()) && Block.class.isAssignableFrom(field.getType()))
					try {
						blocks.remove(field.get(null));
					}
					catch(IllegalArgumentException | IllegalAccessException e) {
						Util.throwUnchecked(e);
					}
	    	}
	    	if(!blocks.isEmpty()) {
	    		List<Block> list = Lists.newArrayList(blocks);
	    		Collections.sort(list, Comparator.comparing(block -> BlockRegistry.getNameFromBlock(block)));
	    		System.err.printf("\n*** -------------------------------------------------------------- ***\n\n");
	    		for(Block block : list) {
	    			String name = BlockRegistry.getNameFromBlock(block);
	    			System.err.printf("\tpublic static final %s %s = get(\"%s\");\n", block.getClass().getSimpleName(), name, name);
	    		}
	    		System.err.printf("\n^^^ " + Blocks.class.getCanonicalName() + ": Blockliste ist unvollständig, Bitte neuen Quellcode einfügen ^^^\n");
	    		System.exit(1);
	    	}
    	}
    }
}
